@@ -4,7 +4,7 @@ use Mojo::ByteStream 'b';
 use Scalar::Util 'blessed';
 use POSIX 'ceil';
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 our @value_list =
   qw/prev
@@ -25,7 +25,7 @@ sub register {
 
   # Load parameter from Config file
   if (my $config_param = $mojo->config('TagHelpers-Pagination')) {
-    $param = { %$config_param, %$param };
+    $param = { %$param, %$config_param };
   };
 
   foreach (@value_list) {
@@ -37,8 +37,8 @@ sub register {
   # Same for 'page'.
   foreach (qw/page current/) {
     if (defined $param->{$_}) {
-      @{$plugin}{$_ . '_start', $_ . '_end'} = split("{$_}", $param->{$_});
-      $plugin->{$_ . '_end'} ||= '';
+      @{$plugin}{"${_}_start", "${_}_end"} = split("{$_}", $param->{$_});
+      $plugin->{"${_}_end"} ||= '';
     };
   };
 
@@ -58,7 +58,6 @@ sub register {
   # Establish pagination helper
   $mojo->helper(
     pagination => sub {
-      shift; # Controller
       return b( $plugin->pagination( @_ ) );
     });
 };
@@ -67,6 +66,7 @@ sub register {
 # Pagination helper
 sub pagination {
   my $self = shift;
+  my $c = shift;
 
   # $_[0] = current page
   # $_[1] = page count
@@ -108,7 +108,7 @@ sub pagination {
     $t =~ s/\%7[bB]$ph\%7[dD]/{$ph}/g;
   };
 
-  my $sub = sublink_gen($t,$ps,$pe,$ph) or return '';
+  my $sub = sublink_gen($c, $t, $ps, $pe, $ph) or return '';
 
   # Pagination string
   my $e;
@@ -220,9 +220,10 @@ sub pagination {
 
 # Sublink function generator
 sub sublink_gen {
+  my $c = shift;
   my ($url, $ps, $pe, $ph) = @_;
 
-  my $s = 'sub {';
+  my $s = 'sub{';
   # $_[0] = number
   # $_[1] = number_shown
 
@@ -237,22 +238,22 @@ sub sublink_gen {
     $s .= 'my $url = $_[0];';
   };
 
-  $s .= 'my$n=$_[1]||' . b($ps)->quote . '.$_[0].' . b($pe)->quote . ';';
-  $s .= q{my $rel='';};
-  $s .= q{if(ref $n){$rel=' rel="'.$n->[1].'"';$n=$n->[0]};};
-  $s .= q!if($url){$url=~s/&/&amp;/g;!;
-  $s .= q{$url=~s/</&lt;/g;};
-  $s .= q{$url=~s/>/&gt;/g;};
-  $s .= q{$url=~s/"/&quot;/g;};
-  $s .= q!$url=~s/'/&#39;/g;};!;
+  $s .= q!my$n=$_[1]||! . b($ps)->quote . '.$_[0].' . b($pe)->quote . ';' .
+        q{my $rel='';} .
+	q{if(ref $n){$rel=' rel="'.$n->[1].'"';$n=$n->[0]};} .
+        q!if($url){$url=~s/&/&amp;/g;! .
+        q{$url=~s/</&lt;/g;} .
+	q{$url=~s/>/&gt;/g;} .
+        q{$url=~s/"/&quot;/g;} .
+        q!$url=~s/'/&#39;/g;};!;
 
   # Create sublink
-  $s .= q{return '<a'.($url?' href="'.$url.'"':'').$rel.'>' . $n . '</a>';};
-  $s .= '}';
+  $s .= q!return '<a'.($url?' href="'.$url.'"':'').$rel.'>' . $n . '</a>';}!;
 
-  my $x = eval($s);
+  my $x = eval $s;
 
-  warn $@ if $@;
+  # Log evaluation error and return
+  $c->app->log->warn($@) and return if $@;
 
   $x;
 };
@@ -324,8 +325,9 @@ L<Mojolicious::Plugin> and implements the following new one.
 
 Called when registering the plugin.
 
-All L<parameters|/PARAMETERS> can be set either on registration or
-as part of the configuration file with the key C<TagHelpers-Pagination>.
+All L<parameters|/PARAMETERS> can be set either as part of the configuration
+file with the key C<TagHelpers-Pagination> or on registration
+(that can be overwritten by configuration).
 
 
 =head1 HELPERS
